Examples
=========

.. toctree::
    :maxdepth: 2


    notebooks/TutorialNotebook.ipynb
    notebooks/AWSDataNotebook.ipynb
    notebooks/LargeDataGladeNotebook.ipynb
    notebooks/Using ZFP to compress.ipynb
    notebooks/CompressionSamples.ipynb
